@@ -1,7 +1,6 @@
 
 package Chart;
-
-our $VERSION = 2.400.10;
+our $VERSION = 2.401.0;
 
 1;
 
@@ -767,8 +766,6 @@ Violine and Box plots
 
 =back
 
-For elaborate plans look into the L<TODO|../TODO>.
-
 =head1 BUGS
 
 Probably quite a few, since it's been completely rewritten.  As usual,
@@ -781,9 +778,48 @@ David Bonner (dbonner@cs.bu.edu)
 
 =head1 MAINTAINER
 
+=over 4
+
+=item *
+
 Chart Group (Chart@fs.wettzell.de)
+
+=item *
+
 Herbert Breunung (lichtkind@cpan.org)
 
+=back
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+
+=item *
+
+Gregor Herrmann (gregoa@debian.org)
+
+=item *
+
+Chris Dolan (chris+rt@chrisdolan.net)
+
+=item *
+
+(jarmzet@yahoo.com)
+
+=item *
+
+Ricardo Signes (rjbs@cpan.org)
+
+=item *
+
+Petr Pisar (ppisar@redhat.com)
+
+
+
+=back
+
+
 =head1 COPYRIGHT
 
 Copyright(c) 1997-1998 by David Bonner, 1999 by Peter Clark,
